@@ -1,8 +1,9 @@
 import click
 
-from gevault.lib.admin import Admin
-from gevault.lib.refresh import Refresh
-from gevault.lib.users import Users
+from lib.admin import Admin
+from lib.refresh import Refresh
+from lib.users import Users
+from lib.tester import Test
 
 @click.group()
 def main():
@@ -14,7 +15,7 @@ def main():
 @click.option('-s', '--server', default="default", required=False)
 def admin(**kwargs):
     bad_function_check(kwargs["function"])
-    admin_class = Admin(config_file=kwargs["config"], server_name=kwargs["server"])
+    admin_class = Admin(config_file=kwargs["config"], server_name=kwargs["server"], silent=False)
     getattr(admin_class, kwargs["function"])()
 
 @main.command()
@@ -24,14 +25,23 @@ def admin(**kwargs):
 @click.option('-s', '--server', default="default", required=False)
 def users(**kwargs):
     bad_function_check(kwargs["function"])
-    users_class = Users(config_file=kwargs["config"], server_name=kwargs["server"])
+    users_class = Users(config_file=kwargs["config"], server_name=kwargs["server"], silent=False)
     getattr(users_class, kwargs["function"])(kwargs.get('user', None))
 
 @main.command()
 @click.option('-c', '--config', default=None, required=False)
 @click.option('-s', '--server', default="default", required=False)
 def refresh(**kwargs):
-    Refresh(config_file=kwargs["config"], server_name=kwargs["server"])
+    Refresh(config_file=kwargs["config"], server_name=kwargs["server"], silent=False)
+
+@main.command()
+@click.argument('function', required=True)
+@click.option('-c', '--config', default=None, required=False)
+@click.option('-s', '--server', default="default", required=False)
+def test(**kwargs):
+    bad_function_check(kwargs["function"])
+    test_class = Test(config_file=kwargs["config"], server_name=kwargs["server"], silent=False)
+    getattr(test_class, kwargs["function"])()
 
 def bad_function_check(function_name):
     if function_name.startswith("_"):
