@@ -3,7 +3,7 @@ from os.path import expanduser
 
 from hvac.exceptions import InvalidRequest
 
-from gevault.lib.vault import Vault
+from lib.vault import Vault
 
 MOUNT_POINT = 'ssh-client-signer'
 SIGNING_ROLE = "vault-signing-role"
@@ -13,8 +13,8 @@ THRESHOLD = 3
 
 class Admin(Vault):
 
-    def __init__(self, config_file=None, server_name="default"):
-        Vault.__init__(self, config_file=config_file, server_name=server_name)
+    def __init__(self, config_file=None, server_name="default", silent=True):
+        Vault.__init__(self, config_file=config_file, server_name=server_name, silent=silent)
 
     def initialize(self):
         """
@@ -29,11 +29,11 @@ class Admin(Vault):
                 text = input("Server already exists in config.  Some values may be overwritten.  Continue? (y/n)")
     
             if text.lower() == "n":
-                print("Exiting...")
+                self._whisper("Exiting...")
                 return
 
         if self.status_check() == 501:
-            print("Status 501:  Initializing Vault...")
+            self._whisper("Status 501:  Initializing Vault...")
             response = self.vault.sys.initialize(SHARES, THRESHOLD)
 
             self.vault.token = response['root_token']
@@ -41,18 +41,18 @@ class Admin(Vault):
                 "rootToken": response['root_token'],
                 "unsealKeys": response['keys']
             })
-            print("Vault Initialized.")
+            self._whisper("Vault Initialized.")
     
         # -------------------------------
 
         if self.status_check() == 503:
-            print("Status 503:  Unsealing Vault...")
+            self._whisper("Status 503:  Unsealing Vault...")
             self.unseal()
 
         # -------------------------------
 
         if self.status_check() == 200:
-            print("Status 200:  Running Setup...")
+            self._whisper("Status 200:  Running Setup...")
             self.set_vault()
             self.__mount_ssh_backend()
             self.write_signing_key()
@@ -63,11 +63,11 @@ class Admin(Vault):
             self.update_config("admin", {"masterToken": self.__create_master_token()})
 
     def __mount_ssh_backend(self):
-        print('Mounting SSH backend...')
+        self._whisper('Mounting SSH backend...')
         try:
             self.vault.sys.enable_secrets_engine('ssh', path=MOUNT_POINT)
         except InvalidRequest:
-            print("SSH backend already mounted...")
+            self._whisper("SSH backend already mounted...")
 
 
     # --- SSH Keys ---
@@ -99,7 +99,7 @@ class Admin(Vault):
             })
         except InvalidRequest as error:
             if "keys are already configured" in error:
-                print("Signing Key already written...")
+                self._whisper("Signing Key already written...")
             else:
                 raise
             
@@ -126,7 +126,10 @@ class Admin(Vault):
 
     def get_public_signing_key(self):
         signing_key_address = "%s/config/ca" % MOUNT_POINT
-        return self.vault.read(signing_key_address)['data']['public_key'].replace("\n", "")
+        key = self.vault.read(signing_key_address)['data']['public_key'].replace("\n", "")
+        self.update_config("admin", {"publicSigningKey": key})
+        self._whisper(key)
+        return key
 
 
     # --- SSH ROLES ---
@@ -142,7 +145,7 @@ class Admin(Vault):
                 default_extensions=[{ "permit-pty": "" }]
             )
         except InvalidRequest:
-            print("Signing Role already created...")
+            self._whisper("Signing Role already created...")
 
     def __create_token_role(self):
         policy = {
@@ -170,9 +173,9 @@ class Admin(Vault):
     # --- Unseal ---
 
     def unseal(self):
-        print("Unsealing Vault...")
+        self._whisper("Unsealing Vault...")
         vault_keys = self._get_unseal_keys()
         self.vault.sys.submit_unseal_key(vault_keys[0])
         self.vault.sys.submit_unseal_key(vault_keys[1])
         self.vault.sys.submit_unseal_key(vault_keys[2])
-        print("Unseal Keys Submitted.")
+        self._whisper("Unseal Keys Submitted.")
