@@ -6,18 +6,17 @@ import requests
 
 from requests.exceptions import ReadTimeout
 
-from gevault.lib.vault import Vault
-from gevault.lib.admin import MOUNT_POINT, SIGNING_ROLE
+from lib.vault import Vault
+from lib.admin import MOUNT_POINT, SIGNING_ROLE
 
-DEFAULT_KEY_NAME = "vault"
 DEFAULT_VAULT_VARIABLE = "VAULT_TOKEN"
 
 class Refresh(Vault):
 
-    def __init__(self, config_file=None, server_name="default"):
-        Vault.__init__(self, config_file=config_file, server_name=server_name)
+    def __init__(self, config_file=None, server_name="default", silent=True):
+        Vault.__init__(self, config_file=config_file, server_name=server_name, silent=silent)
         self.ssh_loc = expanduser("~/.ssh")
-        self.key_name = self.__get_key_name()
+        self.key_name = self._get_key_name()
         self.pubkey_path = "%s/%s.pub" % (self.ssh_loc, self.key_name)
         self.refresh_token = self.__get_refresh_token()
 
@@ -26,7 +25,7 @@ class Refresh(Vault):
         self.create_cert_file(cert)
 
     def gen_ssh_key(self):
-        print("Generating Key Pair...")
+        self._whisper("Generating Key Pair...")
         if isfile(self.pubkey_path): ## keypair exists but is stale
             self._command("echo -e 'y' | ssh-keygen -q -t rsa -b 4096  -N '' -f %s/%s 2>/dev/null <<< y >/dev/null" % (self.ssh_loc, self.key_name))
 
@@ -49,7 +48,7 @@ class Refresh(Vault):
         url = f"{self._get_url()}/v1/{MOUNT_POINT}/sign/{SIGNING_ROLE}"
         headers = {'X-Vault-Token': self.refresh_token}
 
-        print("Requesting Signature...")
+        self._whisper("Requesting Signature...")
         response = req_sess.post(url, headers=headers, data=json.dumps(body), timeout=4)
         response.raise_for_status
         response_dict = json.loads(response.text)
@@ -60,41 +59,31 @@ class Refresh(Vault):
 
 
     def create_cert_file(self, cert):
-        print("Writing Vault Key...")
+        self._whisper("Writing Vault Key...")
         with open(join(self.ssh_loc, "%s-cert.pub" % self.key_name), 'w') as cert_file:
             cert_file.write(cert)
 
-    def __get_key_name(self):
-        if not self.config.get("user", {}).get("sshKeyName", None):
-            key_name = input("SSH key name (default: %s): " % DEFAULT_KEY_NAME)
-            if not key_name:
-                key_name = DEFAULT_KEY_NAME
-            self.update_config("user", {"sshKeyName": key_name})
-        else:
-            key_name = self.config["user"]["sshKeyName"]
-        return key_name
-
     def __get_refresh_token(self):
         # Config Token
         if self.config.get("user", {}).get("refreshToken", None):
-            print("Token found in config file.")
+            self._whisper("Token found in config file.")
             return self.config["user"]["refreshToken"]
 
         # Config Variable
         variable = self.config.get("user", {}).get("refreshTokenVariable", None)
         try:
             token = environ[variable]
-            print("Token found in environment variable %s." % variable)
+            self._whisper("Token found in environment variable %s." % variable)
             return token
         except KeyError:
-            print("Token NOT found in environment variable %s." % variable)
+            self._whisper("Token NOT found in environment variable %s." % variable)
         except TypeError:
             pass
 
         # Default Variable
         try:
             token = environ[DEFAULT_VAULT_VARIABLE]
-            print("Token found in environment variable %s." % DEFAULT_VAULT_VARIABLE)
+            self._whisper("Token found in environment variable %s." % DEFAULT_VAULT_VARIABLE)
             self.update_config("user", {"refreshTokenVariable": DEFAULT_VAULT_VARIABLE})
             return token
         except KeyError:
@@ -105,7 +94,7 @@ class Refresh(Vault):
         self.update_config("user", {"refreshTokenVariable": new_variable})
         try:
             token = environ[new_variable]
-            print("Token found in environment variable %s." % new_variable)
+            self._whisper("Token found in environment variable %s." % new_variable)
             return token
         except KeyError:
             raise Exception("Variable: %s could not be found in environment" % new_variable)
