@@ -1,9 +1,9 @@
-from gevault.lib.vault import Vault
+from lib.vault import Vault
 
 class Users(Vault):
 
-    def __init__(self, config_file=None, server_name="default"):
-        Vault.__init__(self, config_file=config_file, server_name=server_name)
+    def __init__(self, config_file=None, server_name="default", silent=True):
+        Vault.__init__(self, config_file=config_file, server_name=server_name, silent=silent)
 
     def create_user_token(self, user=None):
         if not user:
@@ -25,7 +25,7 @@ class Users(Vault):
         accessor_ids = self.vault.auth.token.list_accessors()['data']['keys']
         accessors = [y for y in [self.vault.auth.token.lookup_accessor(x)['data'] for x in accessor_ids] if y["meta"]]
         accessor_users = [x.get("meta", {}).get("User", None) for x in accessors if x.get("meta").get("User", None)]
-        print(accessor_users)
+        self._whisper(accessor_users)
         return accessor_users
 
     def revoke_user_tokens(self, user=None):
@@ -36,7 +36,7 @@ class Users(Vault):
         revoke_accessors = [x for x in accessors if x["meta"].get("User", None) == user]
         for accessor in revoke_accessors:
             self.vault.auth.token.revoke_accessor(accessor["accessor"])
-        print("Deleted %i tokens" % len(revoke_accessors))
+        self._whisper("Deleted %i tokens" % len(revoke_accessors))
 
         # Config
         config = self.read_config()
@@ -53,5 +53,5 @@ class Users(Vault):
         accessors = [y for y in [self.vault.auth.token.lookup_accessor(x)['data'] for x in accessor_ids] if 'root' not in y['policies']]
         for accessor in accessors:
             self.vault.auth.token.revoke_accessor(accessor["accessor"])
-        print("Deleted %i tokens" % len(accessors))
+        self._whisper("Deleted %i tokens" % len(accessors))
         self.update_config("admin", {"userTokens": {}})
